# Copyright 2016 - Nokia
#
# Licensed under the Apache License, Version 2.0 (the "License"); you may
# not use this file except in compliance with the License. You may obtain
# a copy of the License at
#
#      http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
# WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
# License for the specific language governing permissions and limitations
# under the License.


class CollectdProperties(object):
    RESOURCE_TYPE = 'resource_type'
    RESOURCE_NAME = 'resource_name'
    SEVERITY = 'severity'
    TIME = 'time'
    MESSAGE = 'message'
    HOST = 'host'
    PLUGIN = 'plugin'
    PLUGIN_INSTANCE = 'plugin_instance'
    TYPE_INSTANCE = 'type_instance'
    ID = 'id'
